SystemOrganization addCategory: #ConfigurationOfSameTile!

Object subclass: #ConfigurationOfSameTile
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSameTile'!

!ConfigurationOfSameTile commentStamp: 'StephaneDucasse 2/7/2015 16:32' prior: 0!
(ConfigurationOfSameTile project version: '1.0') load

SameGame browse
	to browse the main class
	
SameGame new openInWorld	
	to play :)!

!ConfigurationOfSameTile class methodsFor: 'private' stamp: 'StephaneDucasse 9/8/2013 20:10'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSameTile class methodsFor: 'catalog' stamp: 'StephaneDucasse 9/9/2013 07:06'!
catalogChangeLog
		
 ^ '- Version 1. 0 12/09/2013 first full configuration 
[[[
(ConfigurationOfSameTile project version: ''1.0'') load
]]]
'
	
	! !

!ConfigurationOfSameTile class methodsFor: 'catalog' stamp: 'StephaneDucasse 9/9/2013 07:05'!
catalogDescription

^ 
'SameTile is a game. Its goal is to get as less as possible as tiles at the end of the game. We can eliminate tiles connected with the same color.'! !

!ConfigurationOfSameTile class methodsFor: 'catalog' stamp: 'StephaneDucasse 9/9/2013 07:08'!
catalogKeyClassesAndExample

	^ 'It is composed of three classes: ==SameGame==, ==SameBoard== and ==SameTile==.

[[[ 
	SameGame new openInWorld.		
]]]	
'! !

!ConfigurationOfSameTile class methodsFor: 'catalog' stamp: 'StephaneDucasse 9/9/2013 07:05'!
catalogKeywords
	^ #(Game Fun Tile Board)
	! !

!ConfigurationOfSameTile class methodsFor: 'private' stamp: 'StephaneDucasse 9/8/2013 20:10'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSameTile class methodsFor: 'metacello support' stamp: 'StephaneDucasse 9/8/2013 20:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSameTile class methodsFor: 'metacello support' stamp: 'StephaneDucasse 9/8/2013 20:10'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSameTile class methodsFor: 'load' stamp: 'StephaneDucasse 9/8/2013 20:10'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfSameTile class methodsFor: 'metacello support' stamp: 'StephaneDucasse 9/8/2013 20:10'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSameTile class methodsFor: 'accessing' stamp: 'StephaneDucasse 9/8/2013 20:10'!
project

	^self new project! !

!ConfigurationOfSameTile class methodsFor: 'metacello support' stamp: 'StephaneDucasse 9/8/2013 20:10'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSameTile methodsFor: 'baselines' stamp: 'StephaneDucasse 9/8/2013 20:30'!
baseline10: spec
	<version: '1.0-baseline'>
	spec
		for: #pharo
		do: [ 
			spec blessing: #baseline.
			spec description: 'First Configuration'.
			spec author: 'StephaneDucasse'.
			spec timestamp: '11/09/2013'.
			spec repository: 'http://www.smalltalkhub.com/mc/StephaneDucasse/SameTile/main'.
			
			spec package: 'SameTile' with: [ spec requires: 'LED' ].
			
			spec
				project: 'LED'
				with: [ 
					spec
						className: 'ConfigurationOfLEDMorph';
						versionString: #stable;
						repository: 'http://smalltalkhub.com/mc/PharoExtras/LEDMorph/main' ].
			spec
				group: 'default' with: #('SameTile');
				group: 'Core' with: #('SameTile') ].
	! !

!ConfigurationOfSameTile methodsFor: 'accessing' stamp: 'StephaneDucasse 9/8/2013 20:11'!
customProjectAttributes
	^#()
	! !

!ConfigurationOfSameTile methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 9/8/2013 20:12'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfSameTile methodsFor: 'accessing' stamp: 'StephaneDucasse 9/8/2013 20:10'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSameTile methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 9/8/2013 20:12'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #common version: '1.0'.
	! !

!ConfigurationOfSameTile methodsFor: 'versions' stamp: 'StephaneDucasse 2/7/2015 16:44'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common
		do: [ spec package: 'SameTile' with: 'SameTile-StephaneDucasse.6' ]
	! !
